@@ -56,7 +56,7 @@ class NWPDataSource(ZarrDataSource):
         n_channels = len(self.channels)
         self._shape_of_example = (
             n_channels,
-            self._total_seq_length,
+            self.total_seq_length,
             image_size_pixels,
             image_size_pixels,
         )
